@@ -42,12 +42,12 @@ cmd = f"/usr/bin/python3 /usr/lib/python3/dist-packages/live_clone/makeLiveStick
 # launch the command makeLiveStick.py
 call(cmd, shell=True)
 
-## change the 3rd partition to swap type
+## change the 5th partition to swap type
 cmd = "fdisk /dev/sda"
 p = Popen(cmd, shell = True, stdin = PIPE, stdout = PIPE)
 inputs = """\
 t
-3
+5
 82
 w
 """
@@ -55,16 +55,16 @@ p.stdin.write(inputs.encode("utf-8"))
 message,err=p.communicate()
 
 ## create the swap
-call("mkswap /dev/sda3", shell = True)
+call("mkswap /dev/sda5", shell = True)
 
 ## write a mention in /etc/fstab
-call("mount /dev/sda4 /mnt", shell = True)
+call("mount /dev/sda6 /mnt", shell = True)
 call("mkdir -p /mnt/rw/etc", shell = True)
 call("mkdir -p /mnt/work", shell = True)
 call("cp /etc/fstab /mnt/rw/etc/", shell = True)
-call("echo '/dev/sda3 none swap sw 0 0' >>  /etc/fstab /mnt/rw/etc/fstab",
+call("echo '/dev/sda5 none swap sw 0 0' >>  /mnt/rw/etc/fstab",
      shell = True)
-call("umount /dev/sda4", shell = True)
+call("umount /dev/sda6", shell = True)
 
 duration = int(time.time() - start)
 print(f"Cloning to hard disk finished, after {duration//60} minutes and {duration % 60:02d} seconds.")
