@@ -6,6 +6,24 @@ import datetime, os, re, glob
 from subprocess import Popen, PIPE, call
 
 class Monitor(QObject):
+    """
+    Parameters of the constructor
+    @param command an executable
+    @param args the command line args for the executable
+    @param mainwindow a QWidget which should have signals monitorfinished
+    and monitorclosed, and a QTabWidget in mainwindow.ui.tabWidget
+    @param index the index of the wanted tab
+    @param rindex the row index to access the table of devices
+    @param buttonMessage the text for the button which appears at
+    the end of the process
+    @param actionMessage a short word to define the ongoing process
+    @param createfiles a list of files which might be created: one can
+    change their ownership if we are running as SUDO
+    @param finishCallback a callback function which should be activated
+    when the monitor finishes. This function takes no argument.
+    @param environ a shell environment; it can be user to get variables
+    SUDO_UID and SUDO_GID
+    """
     def __init__(
             self,
             command, args,
@@ -16,24 +34,6 @@ class Monitor(QObject):
             finishCallback=None,
             environ=None
     ):
-        """
-        the constructor
-        @param command an executable
-        @param args the command line args for the executable
-        @param mainwindow a QWidget which should have signals monitorfinished
-        and monitorclosed, and a QTabWidget in mainwindow.ui.tabWidget
-        @param index the index of the wanted tab
-        @param rindex the row index to access the table of devices
-        @param buttonMessage the text for the button which appears at
-        the end of the process
-        @param actionMessage a short word to define the ongoing process
-        @param createfiles a list of files which might be created: one can
-        change their ownership if we are running as SUDO
-        @param finishCallback a callback function which should be activated
-        when the monitor finishes. This function takes no argument.
-        @param environ a shell environment; it can be user to get variables
-        SUDO_UID and SUDO_GID
-        """
         QObject.__init__(self)
         self.category = "simple_monitor"
         self.index=index
@@ -64,10 +64,25 @@ class Monitor(QObject):
         self.cursor=QTextCursor(self.stdoutTerminal.document());
         self.err_cursor=QTextCursor(self.stderrTerminal.document());
         self.layout = QVBoxLayout(self.w)
-        self.layout.addWidget(QLabel(self.tr("stdout")))
-        self.layout.addWidget(self.stdoutTerminal, stretch=4)
-        self.layout.addWidget(QLabel(self.tr("stderr")))
-        self.layout.addWidget(self.stderrTerminal, stretch=1)
+        split = QSplitter(self.mainwindow.ui.centralwidget)
+        split.setOrientation(Qt.Vertical)
+        split.setChildrenCollapsible(False)
+        self.layout.addWidget(split)
+
+        gb1 = QGroupBox()
+        gb1.setTitle(self.tr("stdout"))
+        layout = QVBoxLayout()
+        split.addWidget(gb1)
+        gb1.setLayout(layout)
+        layout.addWidget(self.stdoutTerminal)
+
+        gb2 = QGroupBox()
+        gb2.setTitle(self.tr("stderr"))
+        layout = QVBoxLayout()
+        split.addWidget(gb2)
+        gb2.setLayout(layout)
+        layout.addWidget(self.stderrTerminal)
+        
         return
 
     def start(self):
